MethodChannelBolddeskSupportSdk class

An implementation of BolddeskSupportSdkPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyCustomFontFamilyInAndroid({required String regular, required String medium, required String semiBold, required String bold}) → Future<void>
override
applyCustomFontFamilyInIOS(String fontFamily) → Future<void>
override
applyTheme(String accentColor, String primaryColor) → Future<void>
override
clearallLocalData() → Future<void>
override
handleAndroidNotification(Map<String, dynamic> body, String notificationIconPath) → Future<void>
override
handleIOSNotification(Map<String, dynamic> data) → Future<void>
override
initialize(String appId, String brandUrl, {void onSuccess(String message)?, void onError(String message)?}) → Future<void>
override
isFromMobileSDK(Map<String, dynamic> userInfo) → Future<bool>
override
isLoggedIn() → Future<bool>
override
loginWithJWTToken(String jwtToken, {void onSuccess(String message)?, void onError(String message)?}) → Future<void>
override
logout() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openArticleDetailsPage(int articleId, String articleSlugTitle) → Future<void>
override
openRecentTickets() → Future<void>
override
openTicketDetailsView(int ticketId) → Future<void>
override
setFCMRegistrationToken(String token) → Future<void>
override
override
setHomeDashboardContent({String? headerName, String? headerDescription, String? kbTitle, String? kbDescription, String? ticketTitle, String? ticketDescription, String? submitButtonText, String? appBarTitle}) → Future<void>
override
setLoggingEnabled(bool enable) → Future<void>
override
setPreferredTheme(String theme) → Future<void>
override
setSystemFontSize(bool enable) → Future<void>
override
showCreateTicket() → Future<void>
override
showHome() → Future<void>
override
showKB() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited